// Parametrized windTunnel

//Run using:
//m4 -P blockMeshDict.m4 > blockMeshDict

//m4 definitions:
m4_changecom(//)m4_changequote([,])
m4_define(calc, [m4_esyscmd(perl -e 'use Math::Trig; printf ($1)')])
m4_define(VCOUNT, 0)
m4_define(vlabel, [[// ]Vertex $1 = VCOUNT m4_define($1, VCOUNT)m4_define([VCOUNT], m4_incr(VCOUNT))])

//Mathematical constants:
m4_define(pi, 3.1415926536)

//m4 spec:
m4_define(testSectionInletWidth, 0.5)
m4_define(testSectionInletHeight, testSectionInletWidth)
m4_define(testSectionLength, calc(2*testSectionInletWidth))
m4_define(testSectionOutletWidth, testSectionInletWidth)
m4_define(testSectionOutletHeight, testSectionInletHeight)
m4_define(testSectionInletArea, calc(testSectionInletWidth*testSectionInletHeight))

m4_define(contractionRatio, 6)

m4_define(contractionInletArea, calc(contractionRatio*testSectionInletArea))
m4_define(contractionInletHeight, calc(sqrt(contractionInletArea)))
m4_define(contractionInletWidth, contractionInletHeight)
m4_define(contractionOutletWidth, testSectionInletWidth)
m4_define(contractionOutletHeight, testSectionInletHeight)
m4_define(contractionLength, calc(2.5*contractionOutletHeight))

m4_define(settlingChamberLength, testSectionInletWidth)
m4_define(settlingChamberOutletWidth, contractionInletWidth)
m4_define(settlingChamberOutletHeight, contractionInletWidth)
m4_define(settlingChamberInletWidth, settlingChamberOutletWidth)
m4_define(settlingChamberInletHeight, settlingChamberOutletWidth)

m4_define(diffuserRatio, 2)
m4_define(diffuserAngle, 2.5)

m4_define(diffuserInletWidth, testSectionOutletWidth)
m4_define(diffuserInletHeight, testSectionOutletWidth)
m4_define(diffuserOutletArea, calc(diffuserRatio*diffuserInletWidth*diffuserInletHeight))
m4_define(diffuserOutletHeight, calc(sqrt(diffuserOutletArea)))
m4_define(diffuserOutletWidth, diffuserOutletHeight)
m4_define(diffuserLength, calc(0.5*diffuserOutletHeight/tan(diffuserAngle*pi/180)-0.5*diffuserInletHeight/tan(diffuserAngle*pi/180)))

m4_define(fanInletHeight, diffuserOutletHeight)
m4_define(fanInletWidth, diffuserOutletWidth)
m4_define(fanOutletHeight, fanInletHeight)
m4_define(fanOutletWidth, fanInletWidth)
m4_define(fanLength, calc(0.5*fanInletHeight))


//plane A settlingChamberInlet
m4_define(xA, 0)

//plane B contractionInlet
m4_define(xB, calc(xA+settlingChamberLength))

//plane C testSectionInlet
m4_define(xC, calc(xB+contractionLength))

//plane D diffuserInlet
m4_define(xD, calc(xC+testSectionLength))

//plane E fanInlet
m4_define(xE, calc(xD+diffuserLength))

//plane F fanOutlet
m4_define(xF, calc(xE+fanLength))

//plane z:
m4_define(z, 0.05)

//spline:
m4_define(alpha, m4_include(currentAlpha))
m4_define(alphaInv, calc(1/alpha) )
m4_define(L, contractionLength)
m4_define(deltaX, calc(contractionLength/10))
m4_define(deltaH, calc(contractionInletHeight**alphaInv - contractionOutletHeight**alphaInv) )
m4_define(Hi, calc(contractionInletHeight**alphaInv) )

m4_define(x1, xB)
m4_define(x2, calc(xB+1*deltaX))
m4_define(x3, calc(xB+2*deltaX))
m4_define(x4, calc(xB+3*deltaX))
m4_define(x5, calc(xB+4*deltaX))
m4_define(x6, calc(xB+5*deltaX))
m4_define(x7, calc(xB+6*deltaX))
m4_define(x8, calc(xB+7.5*deltaX))
m4_define(x9, calc(xB+8.5*deltaX))
m4_define(x10, xC)

m4_define(x2norm, calc(calc(x2-xB)/L))
m4_define(x3norm, calc(calc(x3-xB)/L))
m4_define(x4norm, calc(calc(x4-xB)/L))
m4_define(x5norm, calc(calc(x5-xB)/L))
m4_define(x6norm, calc(calc(x6-xB)/L))
m4_define(x7norm, calc(calc(x7-xB)/L))
m4_define(x8norm, calc(calc(x8-xB)/L))
m4_define(x9norm, calc(calc(x9-xB)/L))

m4_define(x2norm3, calc(x2norm**3))
m4_define(x3norm3, calc(x3norm**3))
m4_define(x4norm3, calc(x4norm**3))
m4_define(x5norm3, calc(x5norm**3))
m4_define(x6norm3, calc(x6norm**3))
m4_define(x7norm3, calc(x7norm**3))
m4_define(x8norm3, calc(x8norm**3))
m4_define(x9norm3, calc(x9norm**3))

m4_define(x2norm4, calc(x2norm**4))
m4_define(x3norm4, calc(x3norm**4))
m4_define(x4norm4, calc(x4norm**4))
m4_define(x5norm4, calc(x5norm**4))
m4_define(x6norm4, calc(x6norm**4))
m4_define(x7norm4, calc(x7norm**4))
m4_define(x8norm4, calc(x8norm**4))
m4_define(x9norm4, calc(x9norm**4))

m4_define(x2norm5, calc(x2norm**5))
m4_define(x3norm5, calc(x3norm**5))
m4_define(x4norm5, calc(x4norm**5))
m4_define(x5norm5, calc(x5norm**5))
m4_define(x6norm5, calc(x6norm**5))
m4_define(x7norm5, calc(x7norm**5))
m4_define(x8norm5, calc(x8norm**5))
m4_define(x9norm5, calc(x9norm**5))

m4_define(eta2, calc( -10*x2norm3 +15*x2norm4 -6*x2norm5) )
m4_define(eta3, calc( -10*x3norm3 +15*x3norm4 -6*x3norm5) )
m4_define(eta4, calc( -10*x4norm3 +15*x4norm4 -6*x4norm5) )
m4_define(eta5, calc( -10*x5norm3 +15*x5norm4 -6*x5norm5) )
m4_define(eta6, calc( -10*x6norm3 +15*x6norm4 -6*x6norm5) )
m4_define(eta7, calc( -10*x7norm3 +15*x7norm4 -6*x7norm5) )
m4_define(eta8, calc( -10*x8norm3 +15*x8norm4 -6*x8norm5) )
m4_define(eta9, calc( -10*x9norm3 +15*x9norm4 -6*x9norm5) )

m4_define(y1, contractionInletHeight)
m4_define(y2, calc( calc(eta2*deltaH+Hi)**alpha) )
m4_define(y3, calc( calc(eta3*deltaH+Hi)**alpha) )
m4_define(y4, calc( calc(eta4*deltaH+Hi)**alpha) )
m4_define(y5, calc( calc(eta5*deltaH+Hi)**alpha) )
m4_define(y6, calc( calc(eta6*deltaH+Hi)**alpha) )
m4_define(y7, calc( calc(eta7*deltaH+Hi)**alpha) )
m4_define(y8, calc( calc(eta8*deltaH+Hi)**alpha) )
m4_define(y9, calc( calc(eta9*deltaH+Hi)**alpha) )
m4_define(y10, contractionOutletHeight)


/*--------------------------------*- C++ -*----------------------------------*\
| =========                 |                                                 |
| \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
|  \\    /   O peration     | Version:  1.7.1                                 |
|   \\  /    A nd           | Web:      www.OpenFOAM.com                      |
|    \\/     M anipulation  |                                                 |
\*---------------------------------------------------------------------------*/
FoamFile
{
    version     2.0;
    format      ascii;

    root            "";
    case            "";
    instance        "";
    local           "";

    class       dictionary;
    object      blockMeshDict;
}
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

convertToMeters 1;

vertices        
(
	// front side
	(xA 0 0) vlabel(A0)
	(xB 0 0) vlabel(B0)
	(xC 0 0) vlabel(C0)
	(xD 0 0) vlabel(D0)
	(xE 0 0) vlabel(E0)
	(xF 0 0) vlabel(F0)
	(xF fanOutletHeight 0) vlabel(F1)
	(xE diffuserOutletHeight 0) vlabel(E1)
	(xD testSectionOutletHeight 0) vlabel(D1)
	(xC contractionOutletHeight 0) vlabel(C1)
	(xB settlingChamberOutletHeight 0) vlabel(B1)
	(xA settlingChamberInletHeight 0) vlabel(A1)

	// back side	
	(xA 0 z) vlabel(A3)
	(xB 0 z) vlabel(B3)
	(xC 0 z) vlabel(C3)
	(xD 0 z) vlabel(D3)
	(xE 0 z) vlabel(E3)
	(xF 0 z) vlabel(F3)
	(xF fanOutletHeight z) vlabel(F2)
	(xE diffuserOutletHeight z) vlabel(E2)
	(xD testSectionOutletHeight z) vlabel(D2)
	(xC contractionOutletHeight z) vlabel(C2)
	(xB settlingChamberOutletHeight z) vlabel(B2)
	(xA settlingChamberInletHeight z) vlabel(A2)

);

blocks          
(
    // settlingChamber	
    hex (B3 A3 A2 B2 B0 A0 A1 B1) (10 40 1) simpleGrading (1 0.05 1)
    // contraction
    hex (C3 B3 B2 C2 C0 B0 B1 C1) (50 40 1) simpleGrading (1 0.05 1)
    // testSection
    hex (D3 C3 C2 D2 D0 C0 C1 D1) (50 40 1) simpleGrading (1 0.05 1)
    // diffuser
    hex (E3 D3 D2 E2 E0 D0 D1 E1) (60 40 1) simpleGrading (1 0.05 1)
    // fan
    hex (F3 E3 E2 F2 F0 E0 E1 F1) (10 40 1) simpleGrading (1 0.05 1)
);

edges           
(
	simpleSpline B1 C1
	(
	(x1 y1 0)
	(x2 y2 0)
	(x3 y3 0)
	(x4 y4 0)
	(x5 y5 0)
	(x6 y6 0)
	(x7 y7 0)
	(x8 y8 0)
	(x9 y9 0)
	(x10 y10 0)
	)

	simpleSpline B2 C2
	(
	(x1 y1 z)
	(x2 y2 z)
	(x3 y3 z)
	(x4 y4 z)
	(x5 y5 z)
	(x6 y6 z)
	(x7 y7 z)
	(x8 y8 z)
	(x9 y9 z)
	(x10 y10 z)
	)

	
);

patches         
(
	patch inlet
	(
	(A3 A0 A1 A2)	
	)

	patch outlet
	(
	(F3 F0 F1 F2)
	)

	wall upperWall
	(
	(B2 B1 A1 A2)
	(C2 C1 B1 B2)
	(D2 D1 C1 C2)
	(E2 E1 D1 D2)
	(F2 F1 E1 E2)
	)

	symmetryPlane axis
	(
	(B3 B0 A0 A3)
	(C3 C0 B0 B3)
	(D3 D0 C0 C3)
	(E3 E0 D0 D3)
	(F3 F0 E0 E3)	
	)

	empty frontAndBack
	(
	(B0 A0 A1 B1)
	(C0 B0 B1 C1)
	(D0 C0 C1 D1)
	(E0 D0 D1 E1)
	(F0 E0 E1 F1)
	(A3 B3 B2 A2)
	(B3 C3 C2 B2)
	(C3 D3 D2 C2)
	(D3 E3 E2 D2)
	(E3 F3 F2 E2)
	)
);

mergePatchPairs
(
);

// ************************************************************************* //
